@@ -1,7 +1,11 @@
-from progressbar import ProgressBar, widgets as pbwidgets
+from typing import Optional
+
+from progressbar import ProgressBar, widgets as pbwidgets  # type: ignore
+
+from progress_checkpoint.common import ProgressFraction, StatusMessage
 
 
-def status_string(status, size=50):
+def status_string(status: str, size: int = 50) -> str:
     status += " " * (size - len(status))
     if len(status) > size:
         status = "..." + status[-size + 3:]
@@ -9,17 +13,17 @@ def status_string(status, size=50):
 
 
 class ProgressbarCheckpoint:
-    def __init__(self):
+    def __init__(self) -> None:
         self.status_label = pbwidgets.FormatLabel(status_string(""))
         self.pb = ProgressBar(1.0, widgets=[self.status_label,
                                             pbwidgets.Percentage(), ' ', pbwidgets.Bar(),
                                             pbwidgets.FormatLabel(" %(elapsed)s "),
                                             pbwidgets.AdaptiveETA(),
                                             ])
-        self.last_status = None
+        self.last_status: Optional[str] = None
         self.pb.start()
 
-    def __call__(self, progress, status=None):
+    def __call__(self, progress: ProgressFraction, status: Optional[StatusMessage] = None) -> None:
         if status != self.last_status:
             if status:
                 self.status_label.format_string = status_string(status)
@@ -32,8 +36,8 @@ class ProgressbarCheckpoint:
 
 
 class ProgressbarCheckpointAsync:
-    def __init__(self):
+    def __init__(self) -> None:
         self.sync = ProgressbarCheckpoint()
 
-    async def __call__(self, *args, **kwargs):
-        return self.sync(*args, **kwargs)
+    async def __call__(self, progress: ProgressFraction, status: Optional[StatusMessage] = None) -> None:
+        return self.sync(progress, status)
